@@ -260,7 +260,7 @@ def also_with_wasm_bigint(f):
         self.skipTest('redundant in bigint test config')
       self.set_setting('WASM_BIGINT')
       self.require_node()
-      self.node_args.append('--experimental-wasm-bigint')
+      self.node_args += shared.node_bigint_flags()
       f(self)
     else:
       f(self)
@@ -422,8 +422,6 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
     return self.get_setting('WASM') != 0
 
   def check_dylink(self):
-    if self.get_setting('MEMORY64'):
-      self.skipTest('MEMORY64 does not yet support dynamic linking')
     if self.get_setting('ALLOW_MEMORY_GROWTH') == 1 and not self.is_wasm():
       self.skipTest('no dynamic linking with memory growth (without wasm)')
     if not self.is_wasm():
@@ -459,7 +457,7 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
     if self.get_setting('MINIMAL_RUNTIME'):
       self.skipTest('node pthreads not yet supported with MINIMAL_RUNTIME')
     self.js_engines = [config.NODE_JS]
-    self.node_args += ['--experimental-wasm-threads', '--experimental-wasm-bulk-memory']
+    self.node_args += shared.node_pthread_flags()
 
   def uses_memory_init_file(self):
     if self.get_setting('SIDE_MODULE') or (self.is_wasm() and not self.get_setting('WASM2JS')):
@@ -486,7 +484,7 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
   def setUp(self):
     super().setUp()
     self.settings_mods = {}
-    self.emcc_args = ['-Werror', '-Wno-limited-postlink-optimizations']
+    self.emcc_args = ['-Wclosure', '-Werror', '-Wno-limited-postlink-optimizations']
     self.ldflags = []
     self.node_args = [
       # Increate stack trace limit to maximise usefulness of test failure reports
@@ -958,7 +956,8 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
 
   def get_library(self, name, generated_libs, configure=['sh', './configure'],  # noqa
                   configure_args=None, make=None, make_args=None,
-                  env_init=None, cache_name_extra='', native=False):
+                  env_init=None, cache_name_extra='', native=False,
+                  force_rebuild=False):
     if make is None:
       make = ['make']
     if env_init is None:
@@ -982,7 +981,7 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
     valid_chars = "_%s%s" % (string.ascii_letters, string.digits)
     cache_name = ''.join([(c if c in valid_chars else '_') for c in cache_name])
 
-    if self.library_cache.get(cache_name):
+    if not force_rebuild and self.library_cache.get(cache_name):
       print('<load %s from cache> ' % cache_name, file=sys.stderr)
       generated_libs = []
       for basename, contents in self.library_cache[cache_name]:
@@ -1204,8 +1203,14 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
     srcfile = test_file(*path)
     out_suffix = kwargs.pop('out_suffix', '')
     outfile = shared.unsuffixed(srcfile) + out_suffix + '.out'
-    expected = read_file(outfile)
-    return self._build_and_run(srcfile, expected, **kwargs)
+    if EMTEST_REBASELINE:
+      expected = None
+    else:
+      expected = read_file(outfile)
+    output = self._build_and_run(srcfile, expected, **kwargs)
+    if EMTEST_REBASELINE:
+      write_file(outfile, output)
+    return output
 
   ## Does a complete test - builds, runs, checks output, etc.
   def _build_and_run(self, filename, expected_output, args=None, output_nicerizer=None,
@@ -1280,11 +1285,19 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
     return js_output
 
   def get_freetype_library(self):
-    if '-Werror' in self.emcc_args:
-      self.emcc_args.remove('-Werror')
-    return self.get_library(os.path.join('third_party', 'freetype'), os.path.join('objs', '.libs', 'libfreetype.a'), configure_args=['--disable-shared', '--without-zlib'])
+    self.emcc_args += [
+      '-Wno-misleading-indentation',
+      '-Wno-unused-but-set-variable',
+      '-Wno-pointer-bool-conversion',
+      '-Wno-shift-negative-value',
+    ]
+    return self.get_library(os.path.join('third_party', 'freetype'),
+                            os.path.join('objs', '.libs', 'libfreetype.a'),
+                            configure_args=['--disable-shared', '--without-zlib'])
 
   def get_poppler_library(self, env_init=None):
+    freetype = self.get_freetype_library()
+
     # The fontconfig symbols are all missing from the poppler build
     # e.g. FcConfigSubstitute
     self.set_setting('ERROR_ON_UNDEFINED_SYMBOLS', 0)
@@ -1294,18 +1307,19 @@ class RunnerCore(unittest.TestCase, metaclass=RunnerMeta):
       '-I' + test_file('third_party/poppler/include')
     ]
 
-    freetype = self.get_freetype_library()
-
     # Poppler has some pretty glaring warning.  Suppress them to keep the
     # test output readable.
-    if '-Werror' in self.emcc_args:
-      self.emcc_args.remove('-Werror')
     self.emcc_args += [
       '-Wno-sentinel',
       '-Wno-logical-not-parentheses',
       '-Wno-unused-private-field',
       '-Wno-tautological-compare',
       '-Wno-unknown-pragmas',
+      '-Wno-shift-negative-value',
+      '-Wno-dynamic-class-memaccess',
+      # Avoid warning about ERROR_ON_UNDEFINED_SYMBOLS being used at compile time
+      '-Wno-unused-command-line-argument',
+      '-Wno-js-compiler',
     ]
     env_init = env_init.copy() if env_init else {}
     env_init['FONTCONFIG_CFLAGS'] = ' '
@@ -1746,8 +1760,8 @@ class BrowserCore(RunnerCore):
     REPORT_RESULT macro to the C code.
     """
     self.set_setting('EXIT_RUNTIME')
-    assert('reporting' not in kwargs)
-    assert('expected' not in kwargs)
+    assert 'reporting' not in kwargs
+    assert 'expected' not in kwargs
     kwargs['reporting'] = Reporting.JS_ONLY
     kwargs['expected'] = 'exit:%d' % assert_returncode
     return self.btest(filename, *args, **kwargs)
@@ -1786,7 +1800,7 @@ class BrowserCore(RunnerCore):
       expected = [expected]
     if EMTEST_BROWSER == 'node':
       self.js_engines = [config.NODE_JS]
-      self.node_args += ['--experimental-wasm-threads', '--experimental-wasm-bulk-memory']
+      self.node_args += shared.node_pthread_flags()
       output = self.run_js('test.js')
       self.assertContained('RESULT: ' + expected[0], output)
     else:
@@ -1887,7 +1901,8 @@ def build_library(name,
     return open(os.path.join(project_dir, 'make.err'), mode)
 
   if EMTEST_BUILD_VERBOSE >= 3:
-    make_args += ['VERBOSE=1']
+    # VERBOSE=1 is cmake and V=1 is for autoconf
+    make_args += ['VERBOSE=1', 'V=1']
 
   try:
     with open_make_out('w') as make_out:
