@@ -13,6 +13,7 @@ import shlex
 import shutil
 import subprocess
 import sys
+from typing import Set, Dict
 from subprocess import PIPE
 
 from . import diagnostics
@@ -27,8 +28,7 @@ from .shared import LLVM_OBJCOPY
 from .shared import run_process, check_call, exit_with_error
 from .shared import path_from_root
 from .shared import asmjs_mangle, DEBUG
-from .shared import TEMP_DIR
-from .shared import CANONICAL_TEMP_DIR, LLVM_DWARFDUMP, demangle_c_symbol_name
+from .shared import LLVM_DWARFDUMP, demangle_c_symbol_name
 from .shared import get_emscripten_temp_dir, exe_suffix, is_c_symbol
 from .utils import WINDOWS
 from .settings import settings
@@ -41,10 +41,9 @@ EXPECTED_BINARYEN_VERSION = 109
 
 # cache results of nm - it can be slow to run
 nm_cache = {}
-_is_ar_cache = {}
-
+_is_ar_cache: Dict[str, bool] = {}
 # the exports the user requested
-user_requested_exports = set()
+user_requested_exports: Set[str] = set()
 
 
 # .. but for Popen, we cannot have doublequotes, so provide functionality to
@@ -205,7 +204,7 @@ def lld_flags_for_executable(external_symbols):
     # Export these two section start symbols so that we can extact the string
     # data that they contain.
     cmd += [
-      '-z', 'stack-size=%s' % settings.TOTAL_STACK,
+      '-z', 'stack-size=%s' % settings.STACK_SIZE,
       '--initial-memory=%d' % settings.INITIAL_MEMORY,
     ]
 
@@ -218,7 +217,7 @@ def lld_flags_for_executable(external_symbols):
         cmd += ['--entry=_emscripten_proxy_main']
       else:
         # TODO(sbc): Avoid passing --no-entry when we know we have an entry point.
-        # For now we need to do this sice the entry point can be either `main` or
+        # For now we need to do this since the entry point can be either `main` or
         # `__main_argv_argc`, but we should address that by using a single `_start`
         # function like we do in STANDALONE_WASM mode.
         cmd += ['--no-entry']
@@ -281,7 +280,7 @@ def get_command_with_possible_response_file(cmd):
     return cmd
 
   logger.debug('using response file for %s' % cmd[0])
-  filename = response_file.create_response_file(cmd[1:], TEMP_DIR)
+  filename = response_file.create_response_file(cmd[1:], shared.TEMP_DIR)
   new_cmd = [cmd[0], "@" + filename]
   return new_cmd
 
@@ -301,24 +300,25 @@ def parse_llvm_nm_symbols(output):
 
   for line in output.split('\n'):
     # Line format: "[archive filename:]object filename: address status name"
-    entry_pos = line.rfind(':')
+    entry_pos = line.rfind(': ')
     if entry_pos < 0:
       continue
 
-    filename_pos = line.rfind(':', 0, entry_pos)
+    filename_end = line.rfind(':', 0, entry_pos)
     # Disambiguate between
     #   C:\bar.o: T main
     # and
     #   /foo.a:bar.o: T main
     # (both of these have same number of ':'s, but in the first, the file name on disk is "C:\bar.o", in second, it is "/foo.a")
-    if filename_pos < 0 or line[filename_pos + 1] in '/\\':
-      filename_pos = entry_pos
+    if filename_end < 0 or line[filename_end + 1] in '/\\':
+      filename_end = entry_pos
 
-    filename = line[:filename_pos]
+    filename = line[:filename_end]
     if entry_pos + 13 >= len(line):
       exit_with_error('error parsing output of llvm-nm: `%s`\nIf the symbol name here contains a colon, and starts with __invoke_, then the object file was likely built with an old version of llvm (please rebuild it).' % line)
 
-    status = line[entry_pos + 11] # Skip address, which is always fixed-length 8 chars.
+    # Skip address, which is always fixed-length 8 chars (plus 2 leading chars `: ` and one trailing space)
+    status = line[entry_pos + 11]
     symbol = line[entry_pos + 13:]
 
     if filename not in symbols:
@@ -387,15 +387,22 @@ def acorn_optimizer(filename, passes, extra_info=None, return_output=False):
     cmd += ['--exportES6']
   if settings.VERBOSE:
     cmd += ['verbose']
-  if not return_output:
-    next = original_filename + '.jso.js'
-    shared.get_temp_files().note(next)
-    check_call(cmd, stdout=open(next, 'w'))
-    save_intermediate(next, '%s.js' % passes[0])
-    return next
-  output = check_call(cmd, stdout=PIPE).stdout
-  return output
+  if return_output:
+    return check_call(cmd, stdout=PIPE).stdout
 
+  acorn_optimizer.counter += 1
+  basename = shared.unsuffixed(original_filename)
+  if '.jso' in basename:
+    basename = shared.unsuffixed(basename)
+  output_file = basename + '.jso%d.js' % acorn_optimizer.counter
+  shared.get_temp_files().note(output_file)
+  cmd += ['-o', output_file]
+  check_call(cmd)
+  save_intermediate(output_file, '%s.js' % passes[0])
+  return output_file
+
+
+acorn_optimizer.counter = 0
 
 WASM_CALL_CTORS = '__wasm_call_ctors'
 
@@ -1296,19 +1303,18 @@ def run_wasm_opt(infile, outfile=None, args=[], **kwargs):  # noqa
   return run_binaryen_command('wasm-opt', infile, outfile, args=args, **kwargs)
 
 
-save_intermediate_counter = 0
-
-
 def save_intermediate(src, dst):
   if DEBUG:
-    global save_intermediate_counter
-    dst = 'emcc-%d-%s' % (save_intermediate_counter, dst)
-    save_intermediate_counter += 1
-    dst = os.path.join(CANONICAL_TEMP_DIR, dst)
+    dst = 'emcc-%d-%s' % (save_intermediate.counter, dst)
+    save_intermediate.counter += 1
+    dst = os.path.join(shared.CANONICAL_TEMP_DIR, dst)
     logger.debug('saving debug copy %s' % dst)
     shutil.copyfile(src, dst)
 
 
+save_intermediate.counter = 0
+
+
 def js_legalization_pass_flags():
   flags = []
   if settings.RELOCATABLE:
